@@ -1,16 +1,16 @@
 package Object::Accessor;
+use if $] > 5.017, 'deprecate';
 
 use strict;
 use Carp            qw[carp croak];
 use vars            qw[$FATAL $DEBUG $AUTOLOAD $VERSION];
 use Params::Check   qw[allow];
-use Data::Dumper;
 
 ### some objects might have overload enabled, we'll need to
 ### disable string overloading for callbacks
 require overload;
 
-$VERSION    = '0.38';
+$VERSION    = '0.48';
 $FATAL      = 0;
 $DEBUG      = 0;
 
@@ -288,7 +288,7 @@ accessors as the current object, but without the data stored in them.
 =cut
 
 ### XXX this creates an object WITH allow handlers at all times.
-### even if the original didnt
+### even if the original didn't
 sub mk_clone {
     my $self    = $_[0];
     my $class   = ref $self;
@@ -296,7 +296,7 @@ sub mk_clone {
     my $clone   = $class->new;
 
     ### split out accessors with and without allow handlers, so we
-    ### don't install dummy allow handers (which makes O::A::lvalue
+    ### don't install dummy allow handlers (which makes O::A::lvalue
     ### warn for example)
     my %hash; my @list;
     for my $acc ( $self->ls_accessors ) {
@@ -430,19 +430,20 @@ sub can {
     my($self, $method) = @_;
 
     ### it's one of our regular methods
-    if( $self->UNIVERSAL::can($method) ) {
-        __PACKAGE__->___debug( "Can '$method' -- provided by package" );
-        return $self->UNIVERSAL::can($method);
+    my $code = $self->UNIVERSAL::can($method);
+    if( $code ) {
+        carp( "Can '$method' -- provided by package" ) if $DEBUG;
+        return $code;
     }
 
     ### it's an accessor we provide;
     if( UNIVERSAL::isa( $self, 'HASH' ) and exists $self->{$method} ) {
-        __PACKAGE__->___debug( "Can '$method' -- provided by object" );
+        carp( "Can '$method' -- provided by object" ) if $DEBUG;
         return sub { $self->$method(@_); }
     }
 
     ### we don't support it
-    __PACKAGE__->___debug( "Cannot '$method'" );
+    carp( "Cannot '$method'" ) if $DEBUG;
     return;
 }
 
@@ -513,7 +514,7 @@ sub ___autoload {
         }
 
         ### need to check the value?
-        if( exists $self->{$method}->[ALLOW] ) {
+        if( defined $self->{$method}->[ALLOW] ) {
 
             ### double assignment due to 'used only once' warnings
             local $Params::Check::VERBOSE = 0;
@@ -576,7 +577,7 @@ sub ___set {
     my $method  = shift or return;
 
     ### you didn't give us a value to set!
-    exists $_[0] or return;
+    @_ or return;
     my $val     = shift;
 
     ### if there's more arguments than $self, then
@@ -611,7 +612,6 @@ sub ___debug {
 
     my $self = shift;
     my $msg  = shift;
-    my $lvl  = shift || 0;
 
     local $Carp::CarpLevel += 1;
 
@@ -709,7 +709,7 @@ See C<perldoc perlsub> for details.
 
         $self->___autoload( $method, @_ ) or return;
 
-        ### *dont* add return to it, or it won't be stored
+        ### *don't* add return to it, or it won't be stored
         ### see perldoc perlsub on lvalue subs
         ### XXX can't use $self->___get( ... ), as we MUST have
         ### the container that's used for the lvalue assign as
@@ -741,7 +741,6 @@ See C<perldoc perlsub> for details.
 ### standard tie class for bound attributes
 {   package Object::Accessor::TIE;
     use Tie::Scalar;
-    use Data::Dumper;
     use base 'Tie::StdScalar';
 
     my %local = ();
